@@ -19,10 +19,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-import pexpect
 import sys
 import time
 
+from lava_android_test.utils import stop_at_pattern
+
 if len(sys.argv) == 1:
     adb_cmd = "adb"
 else:
@@ -30,16 +31,10 @@ else:
 
 logcat_cmd = '%s logcat' % (adb_cmd)
 pattern = "Displayed org.zeroxlab.zeroxbenchmark/.Report"
-try:
-    proc = pexpect.spawn(logcat_cmd, logfile=sys.stdout)
-    id = proc.expect([pattern, pexpect.EOF], timeout=2400)
-    if id == 0:
-        proc.sendcontrol('C')
-except pexpect.TIMEOUT:
+
+if not stop_at_pattern(command=logcat_cmd, pattern=pattern, timeout=2400):
     print "0xbench Test: TIMEOUT Fail"
     sys.exit(1)
-finally:
-    proc.sendcontrol('C')
 
 time.sleep(3)
 sys.exit(0)
